.. _installation:


Installation
============

The django-handyhelpers package is available on Python Package Index (PyPI) and can be installed via pip with the
following command:

.. code-block:: console

    pip install django-handyhelpers
..


Adding django-handyhelpers to your django project
-------------------------------------------------

To include management commands add shared templates, add 'handyhelpers' to the your INSTALLED_APPS of your project's
settings file.

    INSTALLED_APPS = [
        ...
        'handyhelpers',
    ]
